@@ -1,15 +1,20 @@
 import json
-from typing import Any, Callable, Optional, Union
+from typing import Any, Callable, Dict, Optional, Union
 
 import multidict
 import yarl
 
-from .base import Request
+from .base import Header, Method, Request
 from .utils import get_headers_to_enrich
 
 
-def get(url: Union[str, yarl.URL], *, headers: Optional[multidict.CIMultiDictProxy[str]] = None) -> Request:
-    return Request("GET", url, headers, None)
+def get(
+    url: Union[str, yarl.URL],
+    *,
+    headers: Optional[multidict.CIMultiDictProxy[str]] = None,
+    path_parameters: Optional[Dict[str, Any]] = None,
+) -> Request:
+    return build_request(Method.GET, url, headers=headers, path_parameters=path_parameters)
 
 
 def post(
@@ -17,8 +22,9 @@ def post(
     body: Optional[bytes] = None,
     *,
     headers: Optional[multidict.CIMultiDictProxy[str]] = None,
+    path_parameters: Optional[Dict[str, Any]] = None,
 ) -> Request:
-    return Request("POST", url, headers, body)
+    return build_request(Method.POST, url, headers=headers, body=body, path_parameters=path_parameters)
 
 
 def put(
@@ -26,12 +32,18 @@ def put(
     body: Optional[bytes] = None,
     *,
     headers: Optional[multidict.CIMultiDictProxy[str]] = None,
+    path_parameters: Optional[Dict[str, Any]] = None,
 ) -> Request:
-    return Request("PUT", url, headers, body)
+    return build_request(Method.PUT, url, headers=headers, body=body, path_parameters=path_parameters)
 
 
-def delete(url: Union[str, yarl.URL], *, headers: Optional[multidict.CIMultiDictProxy[str]] = None) -> Request:
-    return Request("DELETE", url, headers, None)
+def delete(
+    url: Union[str, yarl.URL],
+    *,
+    headers: Optional[multidict.CIMultiDictProxy[str]] = None,
+    path_parameters: Optional[Dict[str, Any]] = None,
+) -> Request:
+    return build_request(Method.DELETE, url, headers=headers, path_parameters=path_parameters)
 
 
 def post_json(
@@ -43,8 +55,8 @@ def post_json(
     dumps: Callable[[str], Any] = json.dumps,
     content_type: str = "application/json",
 ) -> Request:
-    return _built_json_request(
-        "POST", url, data, headers=headers, encoding=encoding, dumps=dumps, content_type=content_type
+    return build_json_request(
+        Method.POST, url, data, headers=headers, encoding=encoding, dumps=dumps, content_type=content_type
     )
 
 
@@ -57,24 +69,48 @@ def put_json(
     dumps: Callable[[str], Any] = json.dumps,
     content_type: str = "application/json",
 ) -> Request:
-    return _built_json_request(
-        "PUT", url, data, headers=headers, encoding=encoding, dumps=dumps, content_type=content_type
+    return build_json_request(
+        Method.PUT, url, data, headers=headers, encoding=encoding, dumps=dumps, content_type=content_type
     )
 
 
-def _built_json_request(
+def build_json_request(
     method: str,
     url: Union[str, yarl.URL],
     data: Any,
     *,
     headers: Optional[multidict.CIMultiDictProxy[str]] = None,
+    path_parameters: Optional[Dict[str, Any]] = None,
     encoding: str = "utf-8",
     dumps: Callable[[Any], str] = json.dumps,
     content_type: str = "application/json",
 ) -> Request:
     enriched_headers = get_headers_to_enrich(headers)
-    enriched_headers.add("Content-Type", content_type)
+    enriched_headers.add(Header.CONTENT_TYPE, content_type)
 
     body = dumps(data).encode(encoding)
 
-    return Request(method, url, multidict.CIMultiDictProxy[str](enriched_headers), body)
+    return build_request(
+        method=method,
+        url=url,
+        headers=multidict.CIMultiDictProxy[str](enriched_headers),
+        body=body,
+        path_parameters=path_parameters,
+    )
+
+
+def build_request(
+    method: str,
+    url: Union[str, yarl.URL],
+    *,
+    headers: Optional[multidict.CIMultiDictProxy[str]] = None,
+    body: Optional[bytes] = None,
+    path_parameters: Optional[Dict[str, Any]] = None,
+) -> Request:
+    return Request(
+        method=method,
+        url=yarl.URL(url) if isinstance(url, str) else url,
+        headers=headers,
+        body=body,
+        path_parameters=path_parameters,
+    )
